package com.atguigu.log.aspect;

import com.atguigu.exception.BunnyException;
import com.atguigu.log.annotation.Log;
import com.atguigu.log.service.AsyncOperaLogService;
import com.atguigu.log.utils.LogUtil;
import com.atguigu.spzx.model.entity.system.SysOperLog;
import lombok.extern.slf4j.Slf4j;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

@Aspect
@Component
@Slf4j
public class LogAspect {
    @Autowired
    private AsyncOperaLogService asyncOperaLogService;

    @Around(value = "@annotation(sysLog)")
    public Object doAroundAdvice(ProceedingJoinPoint joinPoint, Log sysLog) {
        String title = sysLog.title();
        log.info("请求了===>：{}", title);

        // 构建前置参数
        SysOperLog sysOperLog = new SysOperLog();
        LogUtil.beforeHandleLog(sysLog, joinPoint, sysOperLog);
        Object proceed = null;

        try {
            proceed = joinPoint.proceed();
            // 执行业务方法
            LogUtil.afterHandleLog(sysLog, proceed, sysOperLog, 0, null);
            // 构建响应结果参数
        } catch (Throwable e) {                                 // 代码执行进入到catch中，
            // 业务方法执行产生异常
            LogUtil.afterHandleLog(sysLog, proceed, sysOperLog, 1, e.getMessage());
            throw new BunnyException(e.getMessage());
        }

        // 保存日志数据
        asyncOperaLogService.saveSysOperaLog(sysOperLog);

        // 返回执行结果
        return proceed;
    }
}