package com.atguigu.spzx.manger.controller;

import com.atguigu.log.annotation.Log;
import com.atguigu.spzx.manger.service.CategoryBrandService;
import com.atguigu.spzx.manger.service.ProductService;
import com.atguigu.spzx.model.dto.product.ProductDto;
import com.atguigu.spzx.model.entity.product.Brand;
import com.atguigu.spzx.model.entity.product.Product;
import com.atguigu.spzx.model.vo.result.Result;
import com.atguigu.spzx.model.vo.result.ResultCodeEnum;
import com.github.pagehelper.PageInfo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Tag(name = "商品管理")
@RestController
@RequestMapping(value = "/admin/product/product")
public class ProductController {
    @Autowired
    private ProductService productService;
    @Autowired
    private CategoryBrandService categoryBrandService;

    @Log(title = "列表查询", businessType = 0)
    @Operation(summary = "列表查询", description = "列表查询")
    @GetMapping("{page}/{limit}")
    public Result<PageInfo<Product>> findByPage(@PathVariable Integer page, @PathVariable Integer limit, ProductDto dto) {
        PageInfo<Product> pageInfo = productService.findByPage(page, limit, dto);
        return Result.success(pageInfo);
    }

    @Log(title = "添加功能", businessType = 1)
    @Operation(summary = "添加功能", description = "添加功能")
    @GetMapping("findBrandByCategoryId/{categoryId}")
    public Result<List<Brand>> findBrandByCategoryId(@PathVariable Long categoryId) {
        List<Brand> brandList = categoryBrandService.findBrandByCategoryId(categoryId);
        return Result.success(brandList);
    }

    @Log(title = "保存商品数据接口", businessType = 2)
    @Operation(summary = "保存商品数据接口", description = "保存商品数据接口")
    @PostMapping("save")
    public Result<Product> save(@RequestBody Product product) {
        productService.save(product);
        return Result.success();
    }

    @Log(title = "查询商品详情", businessType = 0)
    @Operation(summary = "查询商品详情", description = "查询商品详情")
    @GetMapping("getById/{id}")
    public Result<Product> getById(@PathVariable Long id) {
        Product product = productService.getById(id);
        return Result.success(product);
    }

    @Log(title = "查询商品详情", businessType = 1)
    @Operation(summary = "保存修改数据接口", description = "保存修改数据接口")
    @PutMapping("updateById")
    public Result<Product> updateById(@Parameter(name = "product", description = "请求参数实体类", required = true) @RequestBody Product product) {
        productService.updateById(product);
        return Result.success();
    }

    @Log(title = "查询商品详情", businessType = 3)
    @Operation(summary = "删除商品", description = "删除商品")
    @DeleteMapping("/deleteById/{id}")
    public Result<Long> deleteById(@Parameter(name = "id", description = "商品id", required = true) @PathVariable Long id) {
        productService.deleteById(id);
        return Result.success();
    }

    @Log(title = "商品审核", businessType = 0)
    @Operation(summary = "商品审核", description = "商品审核")
    @GetMapping("/updateAuditStatus/{id}/{auditStatus}")
    public Result<Product> updateAuditStatus(@PathVariable Long id, @PathVariable Integer auditStatus) {
        productService.updateAuditStatus(id, auditStatus);
        return Result.success();
    }

    @Log(title = "商品上下架", businessType = 0)
    @Operation(summary = "商品上下架", description = "商品上下架")
    @GetMapping("/updateStatus/{id}/{status}")
    public Result<Product> updateStatus(@PathVariable Long id, @PathVariable Integer status) {
        productService.updateStatus(id, status);
        return Result.build(null, ResultCodeEnum.SUCCESS);
    }
}