package com.atguigu.product.service.impl;

import com.alibaba.fastjson.JSON;
import com.atguigu.product.mapper.CategoryMapper;
import com.atguigu.product.service.CategoryService;
import com.atguigu.spzx.model.entity.product.Category;
import com.atguigu.utils.CategoryHelper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.concurrent.TimeUnit;

@Service
public class CategoryServiceImpl implements CategoryService {
    @Autowired
    private CategoryMapper categoryMapper;
    @Autowired
    private RedisTemplate<String, Object> redisTemplate;

    /**
     * 查询以及分类
     *
     * @return 分类实体类列表
     */
    @Override
    public List<Category> selectOneCategory() {
        Object categoryOne = redisTemplate.opsForValue().get("category:one");
        String categoryJsonString = JSON.toJSONString(categoryOne);

        // 如果Redis包含以及分类，直接返回
        if (categoryOne != null) {
            return JSON.parseArray(categoryJsonString, Category.class);
        }
        List<Category> dbCategory = categoryMapper.findOneCategory();

        // 查到的数据放到Redis中
        redisTemplate.opsForValue().set("category:one", dbCategory, 7, TimeUnit.DAYS);

        return dbCategory;
    }

    /**
     * 查询属性结构
     *
     * @return 分类实体类列表
     */
    @Cacheable(value = "category", key = "'all'")
    @Override
    public List<Category> findCategoryTree() {
        // 查询所以分类，返回list集合
        List<Category> categoryList = categoryMapper.findAll();
        return CategoryHelper.buildTree(categoryList);
    }
}
